{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "MMM, G y",
    GyMMMEd => "E, d MMM, G y",
    GyMMMd => "d MMM, G y",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d/M",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    "MMMMW-count-one" => "MMMM\N{U+0aa8}\N{U+0abe} W \N{U+0a85}\N{U+0aa0}\N{U+0ab5}\N{U+0abe}\N{U+0aa1}\N{U+0abf}\N{U+0aaf}\N{U+0abe}",
    "MMMMW-count-other" => "MMMM\N{U+0aa8}\N{U+0abe} W \N{U+0a85}\N{U+0aa0}\N{U+0ab5}\N{U+0abe}\N{U+0aa1}\N{U+0abf}\N{U+0aaf}\N{U+0abe}",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    MMdd => "dd-MM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, d/M/y",
    yMM => "MM-y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM, y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM, y",
    yMd => "d/M/y",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-one" => "Y \N{U+0aa8}\N{U+0abe} w \N{U+0a85}\N{U+0aa0}\N{U+0ab5}\N{U+0abe}\N{U+0aa1}\N{U+0abf}\N{U+0aaf}\N{U+0abe}",
    "yw-count-other" => "Y \N{U+0aa8}\N{U+0abe} w \N{U+0a85}\N{U+0aa0}\N{U+0ab5}\N{U+0abe}\N{U+0aa1}\N{U+0abf}\N{U+0aaf}\N{U+0abe}",
  },
  code => "gu-IN",
  date_format_full => "EEEE, d MMMM, y",
  date_format_long => "d MMMM, y",
  date_format_medium => "d MMM, y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+0ab8}\N{U+0acb}\N{U+0aae}",
    "\N{U+0aae}\N{U+0a82}\N{U+0a97}\N{U+0ab3}",
    "\N{U+0aac}\N{U+0ac1}\N{U+0aa7}",
    "\N{U+0a97}\N{U+0ac1}\N{U+0ab0}\N{U+0ac1}",
    "\N{U+0ab6}\N{U+0ac1}\N{U+0a95}\N{U+0acd}\N{U+0ab0}",
    "\N{U+0ab6}\N{U+0aa8}\N{U+0abf}",
    "\N{U+0ab0}\N{U+0ab5}\N{U+0abf}",
  ],
  day_format_narrow => [
    "\N{U+0ab8}\N{U+0acb}",
    "\N{U+0aae}\N{U+0a82}",
    "\N{U+0aac}\N{U+0ac1}",
    "\N{U+0a97}\N{U+0ac1}",
    "\N{U+0ab6}\N{U+0ac1}",
    "\N{U+0ab6}",
    "\N{U+0ab0}",
  ],
  day_format_wide => [
    "\N{U+0ab8}\N{U+0acb}\N{U+0aae}\N{U+0ab5}\N{U+0abe}\N{U+0ab0}",
    "\N{U+0aae}\N{U+0a82}\N{U+0a97}\N{U+0ab3}\N{U+0ab5}\N{U+0abe}\N{U+0ab0}",
    "\N{U+0aac}\N{U+0ac1}\N{U+0aa7}\N{U+0ab5}\N{U+0abe}\N{U+0ab0}",
    "\N{U+0a97}\N{U+0ac1}\N{U+0ab0}\N{U+0ac1}\N{U+0ab5}\N{U+0abe}\N{U+0ab0}",
    "\N{U+0ab6}\N{U+0ac1}\N{U+0a95}\N{U+0acd}\N{U+0ab0}\N{U+0ab5}\N{U+0abe}\N{U+0ab0}",
    "\N{U+0ab6}\N{U+0aa8}\N{U+0abf}\N{U+0ab5}\N{U+0abe}\N{U+0ab0}",
    "\N{U+0ab0}\N{U+0ab5}\N{U+0abf}\N{U+0ab5}\N{U+0abe}\N{U+0ab0}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+0ab8}\N{U+0acb}\N{U+0aae}",
    "\N{U+0aae}\N{U+0a82}\N{U+0a97}\N{U+0ab3}",
    "\N{U+0aac}\N{U+0ac1}\N{U+0aa7}",
    "\N{U+0a97}\N{U+0ac1}\N{U+0ab0}\N{U+0ac1}",
    "\N{U+0ab6}\N{U+0ac1}\N{U+0a95}\N{U+0acd}\N{U+0ab0}",
    "\N{U+0ab6}\N{U+0aa8}\N{U+0abf}",
    "\N{U+0ab0}\N{U+0ab5}\N{U+0abf}",
  ],
  day_stand_alone_narrow => [
    "\N{U+0ab8}\N{U+0acb}",
    "\N{U+0aae}\N{U+0a82}",
    "\N{U+0aac}\N{U+0ac1}",
    "\N{U+0a97}\N{U+0ac1}",
    "\N{U+0ab6}\N{U+0ac1}",
    "\N{U+0ab6}",
    "\N{U+0ab0}",
  ],
  day_stand_alone_wide => [
    "\N{U+0ab8}\N{U+0acb}\N{U+0aae}\N{U+0ab5}\N{U+0abe}\N{U+0ab0}",
    "\N{U+0aae}\N{U+0a82}\N{U+0a97}\N{U+0ab3}\N{U+0ab5}\N{U+0abe}\N{U+0ab0}",
    "\N{U+0aac}\N{U+0ac1}\N{U+0aa7}\N{U+0ab5}\N{U+0abe}\N{U+0ab0}",
    "\N{U+0a97}\N{U+0ac1}\N{U+0ab0}\N{U+0ac1}\N{U+0ab5}\N{U+0abe}\N{U+0ab0}",
    "\N{U+0ab6}\N{U+0ac1}\N{U+0a95}\N{U+0acd}\N{U+0ab0}\N{U+0ab5}\N{U+0abe}\N{U+0ab0}",
    "\N{U+0ab6}\N{U+0aa8}\N{U+0abf}\N{U+0ab5}\N{U+0abe}\N{U+0ab0}",
    "\N{U+0ab0}\N{U+0ab5}\N{U+0abf}\N{U+0ab5}\N{U+0abe}\N{U+0ab0}",
  ],
  era_abbreviated => [
    "\N{U+0a88}.\N{U+0ab8}.\N{U+0aaa}\N{U+0ac2}\N{U+0ab0}\N{U+0acd}\N{U+0ab5}\N{U+0ac7}",
    "\N{U+0a88}.\N{U+0ab8}.",
  ],
  era_narrow => [
    "\N{U+0a87} \N{U+0ab8} \N{U+0aaa}\N{U+0ac1}",
    "\N{U+0a87}\N{U+0ab8}",
  ],
  era_wide => [
    "\N{U+0a88}\N{U+0ab8}\N{U+0ab5}\N{U+0ac0}\N{U+0ab8}\N{U+0aa8} \N{U+0aaa}\N{U+0ac2}\N{U+0ab0}\N{U+0acd}\N{U+0ab5}\N{U+0ac7}",
    "\N{U+0a87}\N{U+0ab8}\N{U+0ab5}\N{U+0ac0}\N{U+0ab8}\N{U+0aa8}",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%A %d %b %Y %I:%M:%S %p %Z",
  glibc_date_format => "%-d/%-m/%y",
  glibc_datetime_format => "%A %d %b %Y %I:%M:%S %p",
  glibc_time_12_format => "%I:%M:%S %p %Z",
  glibc_time_format => "%I:%M:%S %p %Z",
  language => "Gujarati",
  month_format_abbreviated => [
    "\N{U+0a9c}\N{U+0abe}\N{U+0aa8}\N{U+0acd}\N{U+0aaf}\N{U+0ac1}",
    "\N{U+0aab}\N{U+0ac7}\N{U+0aac}\N{U+0acd}\N{U+0ab0}\N{U+0ac1}",
    "\N{U+0aae}\N{U+0abe}\N{U+0ab0}\N{U+0acd}\N{U+0a9a}",
    "\N{U+0a8f}\N{U+0aaa}\N{U+0acd}\N{U+0ab0}\N{U+0abf}\N{U+0ab2}",
    "\N{U+0aae}\N{U+0ac7}",
    "\N{U+0a9c}\N{U+0ac2}\N{U+0aa8}",
    "\N{U+0a9c}\N{U+0ac1}\N{U+0ab2}\N{U+0abe}\N{U+0a88}",
    "\N{U+0a91}\N{U+0a97}\N{U+0ab8}\N{U+0acd}\N{U+0a9f}",
    "\N{U+0ab8}\N{U+0aaa}\N{U+0acd}\N{U+0a9f}\N{U+0ac7}",
    "\N{U+0a91}\N{U+0a95}\N{U+0acd}\N{U+0a9f}\N{U+0acb}",
    "\N{U+0aa8}\N{U+0ab5}\N{U+0ac7}",
    "\N{U+0aa1}\N{U+0abf}\N{U+0ab8}\N{U+0ac7}",
  ],
  month_format_narrow => [
    "\N{U+0a9c}\N{U+0abe}",
    "\N{U+0aab}\N{U+0ac7}",
    "\N{U+0aae}\N{U+0abe}",
    "\N{U+0a8f}",
    "\N{U+0aae}\N{U+0ac7}",
    "\N{U+0a9c}\N{U+0ac2}",
    "\N{U+0a9c}\N{U+0ac1}",
    "\N{U+0a91}",
    "\N{U+0ab8}",
    "\N{U+0a91}",
    "\N{U+0aa8}",
    "\N{U+0aa1}\N{U+0abf}",
  ],
  month_format_wide => [
    "\N{U+0a9c}\N{U+0abe}\N{U+0aa8}\N{U+0acd}\N{U+0aaf}\N{U+0ac1}\N{U+0a86}\N{U+0ab0}\N{U+0ac0}",
    "\N{U+0aab}\N{U+0ac7}\N{U+0aac}\N{U+0acd}\N{U+0ab0}\N{U+0ac1}\N{U+0a86}\N{U+0ab0}\N{U+0ac0}",
    "\N{U+0aae}\N{U+0abe}\N{U+0ab0}\N{U+0acd}\N{U+0a9a}",
    "\N{U+0a8f}\N{U+0aaa}\N{U+0acd}\N{U+0ab0}\N{U+0abf}\N{U+0ab2}",
    "\N{U+0aae}\N{U+0ac7}",
    "\N{U+0a9c}\N{U+0ac2}\N{U+0aa8}",
    "\N{U+0a9c}\N{U+0ac1}\N{U+0ab2}\N{U+0abe}\N{U+0a88}",
    "\N{U+0a91}\N{U+0a97}\N{U+0ab8}\N{U+0acd}\N{U+0a9f}",
    "\N{U+0ab8}\N{U+0aaa}\N{U+0acd}\N{U+0a9f}\N{U+0ac7}\N{U+0aae}\N{U+0acd}\N{U+0aac}\N{U+0ab0}",
    "\N{U+0a91}\N{U+0a95}\N{U+0acd}\N{U+0a9f}\N{U+0acb}\N{U+0aac}\N{U+0ab0}",
    "\N{U+0aa8}\N{U+0ab5}\N{U+0ac7}\N{U+0aae}\N{U+0acd}\N{U+0aac}\N{U+0ab0}",
    "\N{U+0aa1}\N{U+0abf}\N{U+0ab8}\N{U+0ac7}\N{U+0aae}\N{U+0acd}\N{U+0aac}\N{U+0ab0}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+0a9c}\N{U+0abe}\N{U+0aa8}\N{U+0acd}\N{U+0aaf}\N{U+0ac1}",
    "\N{U+0aab}\N{U+0ac7}\N{U+0aac}\N{U+0acd}\N{U+0ab0}\N{U+0ac1}",
    "\N{U+0aae}\N{U+0abe}\N{U+0ab0}\N{U+0acd}\N{U+0a9a}",
    "\N{U+0a8f}\N{U+0aaa}\N{U+0acd}\N{U+0ab0}\N{U+0abf}\N{U+0ab2}",
    "\N{U+0aae}\N{U+0ac7}",
    "\N{U+0a9c}\N{U+0ac2}\N{U+0aa8}",
    "\N{U+0a9c}\N{U+0ac1}\N{U+0ab2}\N{U+0abe}\N{U+0a88}",
    "\N{U+0a91}\N{U+0a97}\N{U+0ab8}\N{U+0acd}\N{U+0a9f}",
    "\N{U+0ab8}\N{U+0aaa}\N{U+0acd}\N{U+0a9f}\N{U+0ac7}",
    "\N{U+0a91}\N{U+0a95}\N{U+0acd}\N{U+0a9f}\N{U+0acb}",
    "\N{U+0aa8}\N{U+0ab5}\N{U+0ac7}",
    "\N{U+0aa1}\N{U+0abf}\N{U+0ab8}\N{U+0ac7}",
  ],
  month_stand_alone_narrow => [
    "\N{U+0a9c}\N{U+0abe}",
    "\N{U+0aab}\N{U+0ac7}",
    "\N{U+0aae}\N{U+0abe}",
    "\N{U+0a8f}",
    "\N{U+0aae}\N{U+0ac7}",
    "\N{U+0a9c}\N{U+0ac2}",
    "\N{U+0a9c}\N{U+0ac1}",
    "\N{U+0a91}",
    "\N{U+0ab8}",
    "\N{U+0a91}",
    "\N{U+0aa8}",
    "\N{U+0aa1}\N{U+0abf}",
  ],
  month_stand_alone_wide => [
    "\N{U+0a9c}\N{U+0abe}\N{U+0aa8}\N{U+0acd}\N{U+0aaf}\N{U+0ac1}\N{U+0a86}\N{U+0ab0}\N{U+0ac0}",
    "\N{U+0aab}\N{U+0ac7}\N{U+0aac}\N{U+0acd}\N{U+0ab0}\N{U+0ac1}\N{U+0a86}\N{U+0ab0}\N{U+0ac0}",
    "\N{U+0aae}\N{U+0abe}\N{U+0ab0}\N{U+0acd}\N{U+0a9a}",
    "\N{U+0a8f}\N{U+0aaa}\N{U+0acd}\N{U+0ab0}\N{U+0abf}\N{U+0ab2}",
    "\N{U+0aae}\N{U+0ac7}",
    "\N{U+0a9c}\N{U+0ac2}\N{U+0aa8}",
    "\N{U+0a9c}\N{U+0ac1}\N{U+0ab2}\N{U+0abe}\N{U+0a88}",
    "\N{U+0a91}\N{U+0a97}\N{U+0ab8}\N{U+0acd}\N{U+0a9f}",
    "\N{U+0ab8}\N{U+0aaa}\N{U+0acd}\N{U+0a9f}\N{U+0ac7}\N{U+0aae}\N{U+0acd}\N{U+0aac}\N{U+0ab0}",
    "\N{U+0a91}\N{U+0a95}\N{U+0acd}\N{U+0a9f}\N{U+0acb}\N{U+0aac}\N{U+0ab0}",
    "\N{U+0aa8}\N{U+0ab5}\N{U+0ac7}\N{U+0aae}\N{U+0acd}\N{U+0aac}\N{U+0ab0}",
    "\N{U+0aa1}\N{U+0abf}\N{U+0ab8}\N{U+0ac7}\N{U+0aae}\N{U+0acd}\N{U+0aac}\N{U+0ab0}",
  ],
  name => "Gujarati India",
  native_language => "\N{U+0a97}\N{U+0ac1}\N{U+0a9c}\N{U+0ab0}\N{U+0abe}\N{U+0aa4}\N{U+0ac0}",
  native_name => "\N{U+0a97}\N{U+0ac1}\N{U+0a9c}\N{U+0ab0}\N{U+0abe}\N{U+0aa4}\N{U+0ac0} \N{U+0aad}\N{U+0abe}\N{U+0ab0}\N{U+0aa4}",
  native_script => undef,
  native_territory => "\N{U+0aad}\N{U+0abe}\N{U+0ab0}\N{U+0aa4}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1\N{U+0ab2}\N{U+0acb} \N{U+0aa4}\N{U+0acd}\N{U+0ab0}\N{U+0abf}\N{U+0aae}\N{U+0abe}\N{U+0ab8}",
    "2\N{U+0a9c}\N{U+0acb} \N{U+0aa4}\N{U+0acd}\N{U+0ab0}\N{U+0abf}\N{U+0aae}\N{U+0abe}\N{U+0ab8}",
    "3\N{U+0a9c}\N{U+0acb} \N{U+0aa4}\N{U+0acd}\N{U+0ab0}\N{U+0abf}\N{U+0aae}\N{U+0abe}\N{U+0ab8}",
    "4\N{U+0aa5}\N{U+0acb} \N{U+0aa4}\N{U+0acd}\N{U+0ab0}\N{U+0abf}\N{U+0aae}\N{U+0abe}\N{U+0ab8}",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1\N{U+0ab2}\N{U+0acb} \N{U+0aa4}\N{U+0acd}\N{U+0ab0}\N{U+0abf}\N{U+0aae}\N{U+0abe}\N{U+0ab8}",
    "2\N{U+0a9c}\N{U+0acb} \N{U+0aa4}\N{U+0acd}\N{U+0ab0}\N{U+0abf}\N{U+0aae}\N{U+0abe}\N{U+0ab8}",
    "3\N{U+0a9c}\N{U+0acb} \N{U+0aa4}\N{U+0acd}\N{U+0ab0}\N{U+0abf}\N{U+0aae}\N{U+0abe}\N{U+0ab8}",
    "4\N{U+0aa5}\N{U+0acb} \N{U+0aa4}\N{U+0acd}\N{U+0ab0}\N{U+0abf}\N{U+0aae}\N{U+0abe}\N{U+0ab8}",
  ],
  script => undef,
  territory => "India",
  time_format_full => "hh:mm:ss a zzzz",
  time_format_long => "hh:mm:ss a z",
  time_format_medium => "hh:mm:ss a",
  time_format_short => "hh:mm a",
  variant => undef,
  version => 42,
}
